@@ -13,4 +13,4 @@ Copyright © Semantyk 2021. All rights reserved.\
 
 def test_import():
     # Import Declaration | semanytk
-    from src import semantyk
+    import semantyk
